AlbumArtistTag constructor
const
AlbumArtistTag(
- String value, {
- TagProvenance provenance = const TagProvenance.none(),
Creates a new AlbumArtistTag with the specified album artist value.
@param value The name of the album artist, must not be null @param provenance Optional provenance information about the tag source
Example:
final tag = AlbumArtistTag('Album Artist Name');
Implementation
const AlbumArtistTag(
String value, {
super.provenance,
}) : super(
value: value,
key: TagKey.albumArtist,
);